library(testthat)

test_check('Rpoet')
